@@ -4,8 +4,7 @@
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-#ifndef CALENDARSUPPORT_PRINTING_CALPRINTER_H
-#define CALENDARSUPPORT_PRINTING_CALPRINTER_H
+#pragma once
 
 #include "calendarsupport_export.h"
 #include "printplugin.h"
@@ -49,7 +48,7 @@ public:
       \param start Start date
       \param end   End date
     */
-    void setDateRange(const QDate &start, const QDate &end);
+    void setDateRange(QDate start, QDate end);
 
 public Q_SLOTS:
     void updateConfig();
@@ -58,11 +57,7 @@ private Q_SLOTS:
     void doPrint(CalendarSupport::PrintPlugin *selectedStyle, CalendarSupport::CalPrinter::ePrintOrientation dlgorientation, bool preview = false);
 
 public:
-    void print(int type,
-               const QDate &fd,
-               const QDate &td,
-               const KCalendarCore::Incidence::List &selectedIncidences = KCalendarCore::Incidence::List(),
-               bool preview = false);
+    void print(int type, QDate fd, QDate td, const KCalendarCore::Incidence::List &selectedIncidences = KCalendarCore::Incidence::List(), bool preview = false);
     Akonadi::ETMCalendar::Ptr calendar() const;
     KConfig *config() const;
 
@@ -71,8 +66,8 @@ protected:
 
 private:
     Akonadi::ETMCalendar::Ptr mCalendar;
-    QWidget *mParent = nullptr;
-    KConfig *mConfig = nullptr;
+    QWidget *const mParent;
+    KConfig *const mConfig;
     const bool mUniqItem;
 };
 
@@ -105,4 +100,3 @@ private:
 };
 }
 
-#endif
